@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2019 Osimis S.A., Belgium
+ * Copyright (C) 2017-2020 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -84,6 +84,8 @@ static void TranscodePyramid(OrthancWSI::PyramidWriterBase& target,
                              OrthancWSI::ITiledPyramid& source,
                              const OrthancWSI::DicomizerParameters& parameters)
 {
+  LOG(WARNING) << "Transcoding the source pyramid (not re-encoding)";
+
   Orthanc::BagOfTasks tasks;
 
   for (unsigned int i = 0; i < source.GetLevelCount(); i++)
@@ -93,8 +95,6 @@ static void TranscodePyramid(OrthancWSI::PyramidWriterBase& target,
     target.AddLevel(source.GetLevelWidth(i), source.GetLevelHeight(i));
   }
 
-  LOG(WARNING) << "Transcoding the source pyramid";
-
   OrthancWSI::TranscodeTileCommand::PrepareBagOfTasks(tasks, target, source, parameters);
   OrthancWSI::ApplicationToolbox::Execute(tasks, parameters.GetThreadsCount());
 }
@@ -104,6 +104,8 @@ static void ReconstructPyramid(OrthancWSI::PyramidWriterBase& target,
                                OrthancWSI::ITiledPyramid& source,
                                const OrthancWSI::DicomizerParameters& parameters)
 {
+  LOG(WARNING) << "Re-encoding the source pyramid (not transcoding, slower process)";
+
   Orthanc::BagOfTasks tasks;
 
   unsigned int levelsCount = parameters.GetPyramidLevelsCount(target, source);
@@ -132,7 +134,7 @@ static void ReconstructPyramid(OrthancWSI::PyramidWriterBase& target,
   if (lowerLevelsCount != levelsCount)
   {
     LOG(WARNING) << "Constructing the " << lowerLevelsCount << " lower levels of the pyramid";
-    OrthancWSI::TruncatedPyramidWriter truncated(target, lowerLevelsCount);
+    OrthancWSI::TruncatedPyramidWriter truncated(target, lowerLevelsCount, source.GetPhotometricInterpretation());
     OrthancWSI::ReconstructPyramidCommand::PrepareBagOfTasks
       (tasks, truncated, source, lowerLevelsCount + 1, 0, parameters);
     OrthancWSI::ApplicationToolbox::Execute(tasks, parameters.GetThreadsCount());
@@ -160,12 +162,15 @@ static void Recompress(OrthancWSI::IFileTarget& output,
                        OrthancWSI::ITiledPyramid& source,
                        const DcmDataset& dataset,
                        const OrthancWSI::DicomizerParameters& parameters,
-                       const OrthancWSI::ImagedVolumeParameters& volume)
+                       const OrthancWSI::ImagedVolumeParameters& volume,
+                       OrthancWSI::ImageCompression sourceCompression)
 {
   OrthancWSI::TiledPyramidStatistics stats(source);
 
   LOG(WARNING) << "Size of source tiles: " << stats.GetTileWidth() << "x" << stats.GetTileHeight();
-  LOG(WARNING) << "Pixel format: " << Orthanc::EnumerationToString(stats.GetPixelFormat());
+  LOG(WARNING) << "Pixel format: " << Orthanc::EnumerationToString(source.GetPixelFormat());
+  LOG(WARNING) << "Source photometric interpretation: " << Orthanc::EnumerationToString(source.GetPhotometricInterpretation());
+  LOG(WARNING) << "Source compression: " << EnumerationToString(sourceCompression);
   LOG(WARNING) << "Smoothing is " << (parameters.IsSmoothEnabled() ? "enabled" : "disabled");
 
   if (parameters.IsRepaintBackground())
@@ -180,26 +185,67 @@ static void Recompress(OrthancWSI::IFileTarget& output,
     LOG(WARNING) << "No repainting of the background";
   }
 
+  Orthanc::PhotometricInterpretation targetPhotometric;
+  bool transcoding;
+
+  if (parameters.IsForceReencode() ||
+      parameters.IsReconstructPyramid() ||
+      sourceCompression != parameters.GetTargetCompression())
+  {
+    // The tiles of the source image will be re-encoded
+    transcoding = false;
+
+    if (source.GetPixelFormat() == Orthanc::PixelFormat_Grayscale8)
+    {
+      targetPhotometric = source.GetPhotometricInterpretation();
+    }
+    else
+    {
+      switch (parameters.GetTargetCompression())
+      {
+        case OrthancWSI::ImageCompression_Jpeg:
+        case OrthancWSI::ImageCompression_Jpeg2000:
+          targetPhotometric = Orthanc::PhotometricInterpretation_YBRFull422;
+          break;
+
+        case OrthancWSI::ImageCompression_None:
+          targetPhotometric = Orthanc::PhotometricInterpretation_RGB;
+          break;
+
+        default:
+          throw Orthanc::OrthancException(Orthanc::ErrorCode_InternalError);
+      }
+    }
+  }
+  else
+  {
+    // Transcoding: The tiles are copied (no re-encoding)
+    transcoding = true;
+    targetPhotometric = source.GetPhotometricInterpretation();
+  }
+  
   OrthancWSI::DicomPyramidWriter target(output, dataset, 
                                         source.GetPixelFormat(), 
                                         parameters.GetTargetCompression(),
                                         parameters.GetTargetTileWidth(source),
                                         parameters.GetTargetTileHeight(source),
                                         parameters.GetDicomMaxFileSize(),
-                                        volume);
+                                        volume, targetPhotometric);
   target.SetJpegQuality(parameters.GetJpegQuality());
 
   LOG(WARNING) << "Size of target tiles: " << target.GetTileWidth() << "x" << target.GetTileHeight();
+  LOG(WARNING) << "Target photometric interpretation: " << Orthanc::EnumerationToString(targetPhotometric);
 
-  if (target.GetImageCompression() == OrthancWSI::ImageCompression_Jpeg)
+  if (!transcoding &&
+      target.GetImageCompression() == OrthancWSI::ImageCompression_Jpeg)
   {
-    LOG(WARNING) << "Target image compression: Jpeg with quality "
+    LOG(WARNING) << "Target compression: Jpeg with quality "
                  << static_cast<int>(target.GetJpegQuality());
     target.SetJpegQuality(target.GetJpegQuality());
   }
   else
   {
-    LOG(WARNING) << "Target image compression: "
+    LOG(WARNING) << "Target compression: "
                  << OrthancWSI::EnumerationToString(target.GetImageCompression());
   }
 
@@ -219,13 +265,13 @@ static void Recompress(OrthancWSI::IFileTarget& output,
     throw Orthanc::OrthancException(Orthanc::ErrorCode_IncompatibleImageSize);
   }
 
-  if (parameters.IsReconstructPyramid())
+  if (transcoding)
   {
-    ReconstructPyramid(target, stats, parameters);
+    TranscodePyramid(target, stats, parameters);
   }
   else
   {
-    TranscodePyramid(target, stats, parameters);
+    ReconstructPyramid(target, stats, parameters);
   }
 
   target.Flush();
@@ -254,7 +300,8 @@ static DcmDataset* ParseDataset(const std::string& path)
     }
   }
 
-  std::auto_ptr<DcmDataset> dataset(Orthanc::FromDcmtkBridge::FromJson(json, true, true, Orthanc::Encoding_Latin1));
+  std::auto_ptr<DcmDataset> dataset(Orthanc::FromDcmtkBridge::FromJson(json, true, true, Orthanc::Encoding_Latin1,
+                                                                       "" /* no private tag, thus no private creator */));
   if (dataset.get() == NULL)
   {
     LOG(ERROR) << "Cannot convert to JSON file to a DICOM dataset: " << path;
@@ -350,31 +397,15 @@ static void SetupDimension(DcmDataset& dataset,
 
   {
     // Construct tag "Shared Functional Groups Sequence" (5200,9229)
-
-    // In the 2 lines below, remember to switch X/Y when going from physical to pixel coordinates!
-    float spacingX = volume.GetWidth() / static_cast<float>(source.GetLevelHeight(0));
-    float spacingY = volume.GetHeight() / static_cast<float>(source.GetLevelWidth(0));
-
-    std::string spacing = (boost::lexical_cast<std::string>(spacingX) + '\\' +
-                           boost::lexical_cast<std::string>(spacingY));
-
     std::auto_ptr<DcmItem> item(new DcmItem);
 
-    std::auto_ptr<DcmItem> item2(new DcmItem);
-    OrthancWSI::DicomToolbox::SetStringTag(*item2, DCM_SliceThickness, 
-                                           boost::lexical_cast<std::string>(volume.GetDepth()));
-    OrthancWSI::DicomToolbox::SetStringTag(*item2, DCM_PixelSpacing, spacing);
-
     std::auto_ptr<DcmItem> item3(new DcmItem);
     OrthancWSI::DicomToolbox::SetStringTag(*item3, DCM_OpticalPathIdentifier, opticalPathId);
 
     std::auto_ptr<DcmSequenceOfItems> sequence(new DcmSequenceOfItems(DCM_SharedFunctionalGroupsSequence));
-    std::auto_ptr<DcmSequenceOfItems> sequence2(new DcmSequenceOfItems(DCM_PixelMeasuresSequence));
     std::auto_ptr<DcmSequenceOfItems> sequence3(new DcmSequenceOfItems(DCM_OpticalPathIdentificationSequence));
 
-    if (!sequence2->insert(item2.release(), false, false).good() ||
-        !sequence3->insert(item3.release(), false, false).good() ||
-        !item->insert(sequence2.release(), false, false).good() ||
+    if (!sequence3->insert(item3.release(), false, false).good() ||
         !item->insert(sequence3.release(), false, false).good() ||
         !sequence->insert(item.release(), false, false).good() ||
         !dataset.insert(sequence.release(), true /* replace */, false).good())
@@ -445,7 +476,8 @@ static void EnrichDataset(DcmDataset& dataset,
     std::auto_ptr<DcmElement> element(Orthanc::FromDcmtkBridge::FromJson(
                                         Orthanc::DicomTag(DCM_OpticalPathSequence.getGroup(),
                                                           DCM_OpticalPathSequence.getElement()),
-                                        json, false, encoding));
+                                        json, false, encoding,
+                                        "" /* no private tag, thus no private creator */));
     if (!dataset.insert(element.release()).good())
     {
       throw Orthanc::OrthancException(Orthanc::ErrorCode_InternalError);
@@ -863,6 +895,7 @@ static bool ParseParameters(int& exitStatus,
 }
 
 
+
 OrthancWSI::ITiledPyramid* OpenInputPyramid(OrthancWSI::ImageCompression& sourceCompression,
                                             const std::string& path,
                                             const OrthancWSI::DicomizerParameters& parameters)
@@ -954,7 +987,7 @@ int main(int argc, char* argv[])
       EnrichDataset(*dataset, *source, sourceCompression, parameters, volume);
 
       std::auto_ptr<OrthancWSI::IFileTarget> output(parameters.CreateTarget());
-      Recompress(*output, *source, *dataset, parameters, volume);
+      Recompress(*output, *source, *dataset, parameters, volume, sourceCompression);
     }
   }
   catch (Orthanc::OrthancException& e)
