@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2019 Osimis S.A., Belgium
+ * Copyright (C) 2017-2020 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -43,6 +43,7 @@ namespace OrthancWSI
     unsigned int                totalWidth_;
     unsigned int                totalHeight_;
     std::vector<FrameLocation>  frames_;
+    Orthanc::PhotometricInterpretation  photometric_;
 
     void Load(OrthancPlugins::IOrthancConnection&  orthanc,
               const std::string& instanceId);
@@ -66,6 +67,11 @@ namespace OrthancWSI
       return format_;
     }
 
+    Orthanc::PhotometricInterpretation GetPhotometricInterpretation() const
+    {
+      return photometric_;
+    }
+
     unsigned int GetTotalWidth() const
     {
       return totalWidth_;
