@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2019 Osimis S.A., Belgium
+ * Copyright (C) 2017-2020 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -123,14 +123,15 @@ namespace OrthancWSI
 
 
   bool HierarchicalTiff::GetCurrentPixelFormat(Orthanc::PixelFormat& pixelFormat,
+                                               Orthanc::PhotometricInterpretation& photometric,
                                                ImageCompression compression)
   {
     // http://www.awaresystems.be/imaging/tiff/tifftags/baseline.html
 
-    uint16_t channels, photometric, bpp, planar;
+    uint16_t channels, photometricTiff, bpp, planar;
     if (!TIFFGetField(tiff_, TIFFTAG_SAMPLESPERPIXEL, &channels) ||
         channels == 0 ||
-        !TIFFGetField(tiff_, TIFFTAG_PHOTOMETRIC, &photometric) ||
+        !TIFFGetField(tiff_, TIFFTAG_PHOTOMETRIC, &photometricTiff) ||
         !TIFFGetField(tiff_, TIFFTAG_BITSPERSAMPLE, &bpp) ||
         !TIFFGetField(tiff_, TIFFTAG_PLANARCONFIG, &planar))
     {
@@ -140,10 +141,31 @@ namespace OrthancWSI
     if (compression == ImageCompression_Jpeg &&
         channels == 3 &&     // This is a color image
         bpp == 8 &&
-        photometric == PHOTOMETRIC_YCBCR &&
         planar == PLANARCONFIG_CONTIG)  // This is interleaved RGB
     {
       pixelFormat = Orthanc::PixelFormat_RGB24;
+
+      switch (photometricTiff)
+      {
+        case PHOTOMETRIC_YCBCR:
+          photometric = Orthanc::PhotometricInterpretation_YBRFull422;
+          return true;
+          
+        case PHOTOMETRIC_RGB:
+          photometric = Orthanc::PhotometricInterpretation_RGB;
+          return true;
+
+        default:
+          LOG(ERROR) << "Unknown photometric interpretation in TIFF: " << photometricTiff;
+          return false;
+      }
+    }
+    else if (compression == ImageCompression_Jpeg &&
+             channels == 1 &&     // This is a grayscale image
+             bpp == 8)
+    {
+      pixelFormat = Orthanc::PixelFormat_Grayscale8;
+      photometric = Orthanc::PhotometricInterpretation_Monochrome2;
     }
     else
     {
@@ -164,6 +186,7 @@ namespace OrthancWSI
       uint32_t w, h, tw, th;
       ImageCompression compression;
       Orthanc::PixelFormat pixelFormat;
+      Orthanc::PhotometricInterpretation photometric;
 
       if (TIFFSetDirectory(tiff_, pos) &&
           TIFFGetField(tiff_, TIFFTAG_IMAGEWIDTH, &w) &&
@@ -175,7 +198,7 @@ namespace OrthancWSI
           tw > 0 &&
           th > 0 &&
           GetCurrentCompression(compression) &&
-          GetCurrentPixelFormat(pixelFormat, compression))
+          GetCurrentPixelFormat(pixelFormat, photometric, compression))
       {
         if (first)
         {
@@ -183,12 +206,14 @@ namespace OrthancWSI
           tileHeight_ = th;
           compression_ = compression;
           pixelFormat_ = pixelFormat;
+          photometric_ = photometric;
           first = false;
         }
         else if (tw != tileWidth_ ||
                  th != tileHeight_ ||
                  compression_ != compression ||
-                 pixelFormat_ != pixelFormat)
+                 pixelFormat_ != pixelFormat ||
+                 photometric_ != photometric)
         {
           LOG(ERROR) << "The tile size or compression of the TIFF file varies along levels, this is not supported";
           return false;
