@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2019 Osimis S.A., Belgium
+ * Copyright (C) 2017-2020 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -55,6 +55,7 @@ namespace OrthancWSI
     unsigned int          tileWidth_;
     unsigned int          tileHeight_;
     std::vector<Level>    levels_;
+    Orthanc::PhotometricInterpretation  photometric_;
 
     void Finalize();
 
@@ -63,6 +64,7 @@ namespace OrthancWSI
     bool GetCurrentCompression(ImageCompression& compression);
 
     bool GetCurrentPixelFormat(Orthanc::PixelFormat& pixelFormat,
+                               Orthanc::PhotometricInterpretation& photometric,
                                ImageCompression compression);
 
     bool Initialize();
@@ -105,6 +107,11 @@ namespace OrthancWSI
       return pixelFormat_;
     }
 
+    virtual Orthanc::PhotometricInterpretation GetPhotometricInterpretation() const
+    {
+      return photometric_;
+    }
+
     ImageCompression GetImageCompression()
     {
       return compression_;
