@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2019 Osimis S.A., Belgium
+ * Copyright (C) 2017-2020 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -168,7 +168,7 @@ namespace OrthancWSI
                              void *userData)
       {
         OpenJpegInput& that = *reinterpret_cast<OpenJpegInput*>(userData);
-        assert(that.position_ >= 0 && that.position_ <= that.size_);
+        assert(that.position_ <= that.size_);
         assert(size >= 0);
 
         if (that.position_ == that.size_)
