@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2019 Osimis S.A., Belgium
+ * Copyright (C) 2017-2020 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -140,8 +140,44 @@ namespace OrthancWSI
       {
         writer = new MultiframeDicomWriter
           (dataset_, GetImageCompression(), GetPixelFormat(), level.width_, level.height_, 
-           GetTileWidth(), GetTileHeight());
+           GetTileWidth(), GetTileHeight(), photometric_);
         writers_[z] = writer;
+
+        {
+          // Fix issue 139: The PixelSpacing information changes at each level
+          // https://bitbucket.org/sjodogne/orthanc/issues/139/orthancwsidicomizer-pixelspacing
+
+          // In the 2 lines below, remember to switch X/Y when going from physical to pixel coordinates!
+          float spacingX = volume_.GetWidth() / static_cast<float>(level.height_);
+          float spacingY = volume_.GetHeight() / static_cast<float>(level.width_);
+
+          std::string spacing = (boost::lexical_cast<std::string>(spacingX) + '\\' +
+                                 boost::lexical_cast<std::string>(spacingY));
+
+          std::auto_ptr<DcmItem> item(new DcmItem);
+
+          std::auto_ptr<DcmItem> item2(new DcmItem);
+          OrthancWSI::DicomToolbox::SetStringTag(*item2, DCM_SliceThickness, 
+                                                 boost::lexical_cast<std::string>(volume_.GetDepth()));
+          OrthancWSI::DicomToolbox::SetStringTag(*item2, DCM_PixelSpacing, spacing);
+
+          std::auto_ptr<DcmSequenceOfItems> sequence2(new DcmSequenceOfItems(DCM_PixelMeasuresSequence));
+          if (!sequence2->insert(item2.release(), false, false).good())
+          {
+            throw Orthanc::OrthancException(Orthanc::ErrorCode_InternalError);
+          }
+
+          DcmSequenceOfItems* sequence = NULL;
+          if (!writer->GetSharedTags().findAndGetSequence(DCM_SharedFunctionalGroupsSequence, sequence).good() ||
+              sequence == NULL ||
+              sequence->card() != 1 ||
+              sequence->getItem(0) == NULL ||
+              !sequence->getItem(0)->insert(sequence2.release(), false, false).good())
+          {
+            // This sequence should have been created by "SetupDimension()" in Dicomizer.cpp
+            throw Orthanc::OrthancException(Orthanc::ErrorCode_InternalError);
+          }
+        }
       }
 
       std::auto_ptr<DcmItem> functionalGroup(CreateFunctionalGroup(writer->GetFramesCount() + 1,
@@ -166,14 +202,16 @@ namespace OrthancWSI
                                          unsigned int tileWidth,
                                          unsigned int tileHeight,
                                          size_t maxSize,   // If "0", no automatic flushing
-                                         const ImagedVolumeParameters&  volume) :
+                                         const ImagedVolumeParameters&  volume,
+                                         Orthanc::PhotometricInterpretation photometric) :
     PyramidWriterBase(pixelFormat, compression, tileWidth, tileHeight),
     target_(target),
     dataset_(dataset),
     maxSize_(maxSize),
     countTiles_(0),
     countInstances_(0),
-    volume_(volume)
+    volume_(volume),
+    photometric_(photometric)
   {
   }
 
