@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2019 Osimis S.A., Belgium
+ * Copyright (C) 2017-2020 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -46,7 +46,8 @@ namespace OrthancWSI
     unsigned int              nextX_;
     unsigned int              nextY_;
     bool                      isFirst_;
- 
+    Orthanc::PhotometricInterpretation  photometric_;
+    
     void Close()
     {
       TIFFClose(tiff_);
@@ -78,7 +79,8 @@ namespace OrthancWSI
                            Orthanc::PixelFormat pixelFormat, 
                            ImageCompression compression,
                            unsigned int tileWidth,
-                           unsigned int tileHeight);
+                           unsigned int tileHeight,
+                           Orthanc::PhotometricInterpretation photometric);
 
     virtual ~HierarchicalTiffWriter();
 
