@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2019 Osimis S.A., Belgium
+ * Copyright (C) 2017-2020 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -63,7 +63,8 @@ namespace OrthancWSI
                           unsigned int width,
                           unsigned int height,
                           unsigned int tileWidth,
-                          unsigned int tileHeight);
+                          unsigned int tileHeight,
+                          Orthanc::PhotometricInterpretation photometric);
 
     void AddFrame(const std::string& frame,
                   DcmItem* functionalGroup);   // This takes the ownership
@@ -90,5 +91,10 @@ namespace OrthancWSI
     {
       return height_;
     }
+
+    DcmDataset& GetSharedTags()
+    {
+      return sharedTags_;
+    }
   };
 }
