@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2019 Osimis S.A., Belgium
+ * Copyright (C) 2017-2020 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -27,13 +27,15 @@
 namespace OrthancWSI
 {
   TruncatedPyramidWriter::TruncatedPyramidWriter(IPyramidWriter& lower,
-                                                 unsigned int upperLevelIndex) :
+                                                 unsigned int upperLevelIndex,
+                                                 Orthanc::PhotometricInterpretation photometric) :
     lowerLevels_(lower),
     upperLevel_(lower.GetPixelFormat(),
                 lower.GetCountTilesX(upperLevelIndex),
                 lower.GetCountTilesY(upperLevelIndex),
                 lower.GetTileWidth(),
-                lower.GetTileHeight()),
+                lower.GetTileHeight(),
+                photometric),
     upperLevelIndex_(upperLevelIndex)
   {
     if (upperLevelIndex > lower.GetLevelCount())
